# ArgAtomicFilter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**ignore_case** | **bool** |  | [optional] 
**left** | [**OperatorArgument**](OperatorArgument.md) |  | [optional] 
**operator** | [**FilterOperatorID**](FilterOperatorID.md) |  | [optional] 
**right** | [**OperatorArgument**](OperatorArgument.md) |  | [optional] 
**type** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


